@@ -2,6 +2,8 @@ tmp <- tempfile(fileext = ".txt")
 writeLines("R’s interpreter", tmp)
 
 test_that("non-ASCII characters listed as tibble", {
+  skip_on_os("mac")
+  skip_on_os("windows")
   dat <- non_ascii(path = tmp)
   if (!is.data.frame(dat)) {
     skip("dat was not converted to a data frame")
@@ -15,6 +17,8 @@ hl <- function(string) {
 }
 
 test_that("non-ASCII characters can be highlighted", {
+  skip_on_os("mac")
+  skip_on_os("windows")
   dat <- non_ascii(path = tmp, highlight = hl)
   if (!is.data.frame(dat)) {
     skip("dat was not converted to a data frame")
@@ -28,6 +32,8 @@ tmp2 <- tempfile(fileext = ".txt")
 writeLines("R's interpreter", tmp2)
 
 test_that("Lack of non-ASCII characters return FALSE", {
+  skip_on_os("mac")
+  skip_on_os("windows")
   dat <- non_ascii(path = tmp2)
   expect_false(dat)
 })
